@@ -22,7 +22,7 @@
 
 class user_config_reset implements pts_option_interface
 {
-	const doc_section = 'Other';
+	const doc_section = 'User Configuration';
 	const doc_description = 'This option can be used for resetting the Phoronix Test Suite user configuration file to its default state.';
 
 	public static function run($r)
