@@ -203,9 +203,10 @@ class pts_test_execution
 
 			if(!$test_run_manager->DEBUG_no_test_execution_just_result_parse && $restored_from_cache == false)
 			{
+				$test_prepend = getenv('TEST_EXEC_PREPEND') != null ? getenv('TEST_EXEC_PREPEND') . ' ': null;
 				pts_client::$display->test_run_instance_header($test_run_request);
 				sleep(1);
-				$test_run_command = 'cd ' . $to_execute . ' && ' . $execute_binary_prepend . './' . $execute_binary . ' ' . $pts_test_arguments . ' 2>&1';
+				$test_run_command = 'cd ' . $to_execute . ' && ' . $test_prepend . $execute_binary_prepend . './' . $execute_binary . ' ' . $pts_test_arguments . ' 2>&1';
 
 				pts_client::test_profile_debug_message('Test Run Command: ' . $test_run_command);
 
@@ -222,7 +223,12 @@ class pts_test_execution
 				{
 					//$test_result_std_output = pts_client::shell_exec($test_run_command, $test_extra_runtime_variables);
 					$descriptorspec = array(0 => array('pipe', 'r'), 1 => array('pipe', 'w'), 2 => array('pipe', 'w'));
-					$test_process = proc_open('exec ' . $execute_binary_prepend . './' . $execute_binary . ' ' . $pts_test_arguments . ' 2>&1', $descriptorspec, $pipes, $to_execute, array_merge($_ENV, pts_client::environmental_variables(), $test_extra_runtime_variables));
+
+					if(getenv('XAUTHORITY'))
+					{
+						$test_extra_runtime_variables['XAUTHORITY'] = getenv('XAUTHORITY');
+					}
+					$test_process = proc_open($test_prepend . 'exec ' . $execute_binary_prepend . './' . $execute_binary . ' ' . $pts_test_arguments . ' 2>&1', $descriptorspec, $pipes, $to_execute, array_merge($_ENV, pts_client::environmental_variables(), $test_extra_runtime_variables));
 
 					if(is_resource($test_process))
 					{
@@ -237,7 +243,22 @@ class pts_test_execution
 
 				$test_run_time = microtime(true) - $test_run_time_start;
 				$test_run_request->test_run_times[] = $test_run_time;
-				$produced_monitoring_result = $is_monitoring ? pts_test_result_parser::system_monitor_task_post_test($test_run_request) : false;
+
+				$exit_status_pass = true;
+				if(is_file($test_directory . 'test-exit-status'))
+				{
+					// If the test script writes its exit status to ~/test-exit-status, if it's non-zero the test run failed
+					$exit_status = pts_file_io::file_get_contents($test_directory . 'test-exit-status');
+					unlink($test_directory . 'test-exit-status');
+
+					if($exit_status != 0)
+					{
+						//self::test_run_instance_error($test_run_manager, $test_run_request, 'The test quit with a non-zero exit status.');
+						$exit_status_pass = false;
+					}
+				}
+
+				$produced_monitoring_result = $is_monitoring ? pts_test_result_parser::system_monitor_task_post_test($test_run_request, $exit_status_pass) : false;
 			}
 			else
 			{
@@ -246,6 +267,7 @@ class pts_test_execution
 					pts_client::$display->test_run_message('Utilizing Data From Shared Cache');
 				}
 				$test_run_time = 0;
+				$exit_status_pass = true;
 			}
 
 
@@ -262,27 +284,19 @@ class pts_test_execution
 			}
 			$test_run_request->test_result_standard_output = $test_result_std_output;
 
-			$exit_status_pass = true;
-			if(is_file($test_directory . 'test-exit-status'))
+			if($exit_status_pass == false)
 			{
 				// If the test script writes its exit status to ~/test-exit-status, if it's non-zero the test run failed
-				$exit_status = pts_file_io::file_get_contents($test_directory . 'test-exit-status');
-				unlink($test_directory . 'test-exit-status');
-
-				if($exit_status != 0)
+				self::test_run_instance_error($test_run_manager, $test_run_request, 'The test quit with a non-zero exit status.');
+				if($is_expected_last_run && is_file($test_log_file))
 				{
-					self::test_run_instance_error($test_run_manager, $test_run_request, 'The test quit with a non-zero exit status.');
-					if($is_expected_last_run && is_file($test_log_file))
-					{
-						$scan_log = pts_file_io::file_get_contents($test_log_file);
-						$test_run_error = pts_tests::scan_for_error($scan_log, $test_run_request->test_profile->get_test_executable_dir());
+					$scan_log = pts_file_io::file_get_contents($test_log_file);
+					$test_run_error = pts_tests::scan_for_error($scan_log, $test_run_request->test_profile->get_test_executable_dir());
 
-						if($test_run_error)
-						{
-							self::test_run_instance_error($test_run_manager, $test_run_request, 'E: ' . $test_run_error);
-						}
+					if($test_run_error)
+					{
+						self::test_run_instance_error($test_run_manager, $test_run_request, 'E: ' . $test_run_error);
 					}
-					$exit_status_pass = false;
 				}
 			}
 
@@ -343,11 +357,12 @@ class pts_test_execution
 				// The later check above ensures if the test is failing often the run count won't uselessly be increasing
 				// Should we increase the run count?
 				$increase_run_count = false;
+				$runs_ignored_count = count($ignore_runs);
 
-				if($defined_times_to_run == ($i + 1) && $times_result_produced > 0 && $times_result_produced < $defined_times_to_run && $i < 64)
+				if($defined_times_to_run == ($i + 1) && $times_result_produced > 0 && ($times_result_produced + $runs_ignored_count) < $defined_times_to_run && $i < 64)
 				{
 					// At least one run passed, but at least one run failed to produce a result. Increase count to try to get more successful runs
-					$increase_run_count = $defined_times_to_run - $times_result_produced;
+					$increase_run_count = $defined_times_to_run - $times_result_produced + $runs_ignored_count;
 				}
 				else if($times_result_produced >= 2)
 				{
@@ -544,11 +559,6 @@ class pts_test_execution
 				}
 			}
 
-			if(empty($arguments_description))
-			{
-				$arguments_description = 'Phoronix Test Suite v' . PTS_VERSION;
-			}
-
 			foreach(pts_client::environmental_variables() as $key => $value)
 			{
 				$arguments_description = str_replace('$' . $key, $value, $arguments_description);
@@ -746,8 +756,26 @@ class pts_test_execution
 
 						$test_result->test_result_buffer = new pts_test_result_buffer();
 						$test_result->test_result_buffer->add_test_result($test_run_manager->get_results_identifier(), $test_result->active->get_result(), $test_result->active->get_values_as_string(), pts_test_run_manager::process_json_report_attributes($test_result), $test_result->active->get_min_result(), $test_result->active->get_max_result());
-						$test_run_manager->result_file->add_result($test_result);
+						$added_comparison_hash = $test_run_manager->result_file->add_result($test_result);
 						$generated_result_count++;
+
+						// The merged data, get back the merged test_result object
+						$results_comparison = clone $test_run_manager->result_file->get_result($added_comparison_hash);
+						if($results_comparison && $results_comparison->test_result_buffer->get_count() > 1)
+						{
+							pts_client::$display->test_run_success_inline($results_comparison);
+						}
+						pts_module_manager::module_process('__test_run_success_inline_result', $results_comparison);
+					}
+					else
+					{
+						// Not a saved result
+						$test_result->test_result_buffer = new pts_test_result_buffer();
+						$test_result->test_result_buffer->add_test_result('Result', $test_result->active->get_result(), $test_result->active->get_values_as_string(), pts_test_run_manager::process_json_report_attributes($test_result), $test_result->active->get_min_result(), $test_result->active->get_max_result());
+						$temp_result_file = new pts_result_file(null);
+						$added_comparison_hash = $temp_result_file->add_result($test_result);
+						$results_comparison = clone $temp_result_file->get_result($added_comparison_hash);
+						pts_module_manager::module_process('__test_run_success_inline_result', $results_comparison);
 					}
 				}
 			}
