@@ -37,6 +37,9 @@ class phodevi_cpu extends phodevi_device_interface
 			case 'model':
 				$property = new phodevi_device_property('cpu_model', phodevi::smart_caching);
 				break;
+			case 'model-and-speed':
+				$property = new phodevi_device_property('cpu_model_and_speed', phodevi::smart_caching);
+				break;
 			case 'mhz-default-frequency':
 				$property = new phodevi_device_property('cpu_default_frequency_mhz', phodevi::smart_caching);
 				break;
@@ -80,6 +83,19 @@ class phodevi_cpu extends phodevi_device_interface
 
 		return $model . ' (' . pts_strings::plural_handler($core_count, 'Core') . ')';
 	}
+	public static function cpu_model_and_speed()
+	{
+		$model = phodevi::read_property('cpu', 'model');
+
+		// Append the processor frequency to string
+		if(($freq = phodevi::read_property('cpu', 'default-frequency')) > 0)
+		{
+			$model = str_replace($freq . 'GHz', null, $model); // we'll replace it if it's already in the string
+			$model .= ' @ ' . $freq . 'GHz';
+		}
+
+		return $model;
+	}
 	public static function cpu_core_count()
 	{
 		$info = null;
@@ -478,7 +494,8 @@ class phodevi_cpu extends phodevi_device_interface
 			'fma4' => (1 << 15), // FMA4 Instruction Set
 			'rdrand' => (1 << 16), // Intel Bull Mountain RDRAND - Ivy Bridge
 			'fsgsbase' => (1 << 17), // FSGSBASE - Ivy Bridge AVX
-			'bmi2' => (1 << 18) // Intel Haswell has BMI2
+			'bmi2' => (1 << 18), // Intel Haswell has BMI2
+			'avx512cd' => (1 << 19) // AVX-512
 			);
 	}
 	public static function get_cpu_feature_constant($constant)
@@ -541,7 +558,7 @@ class phodevi_cpu extends phodevi_device_interface
 		}
 
 		// Check for other instruction sets
-		foreach(array('avx2', 'avx', 'xop', 'fma3', 'fma4', 'rdrand', 'fsgsbase') as $instruction_set)
+		foreach(array('avx512cd', 'avx2', 'avx', 'xop', 'fma3', 'fma4', 'rdrand', 'fsgsbase') as $instruction_set)
 		{
 			if(($cpu_flags & self::get_cpu_feature_constant($instruction_set)))
 			{
@@ -583,6 +600,11 @@ class phodevi_cpu extends phodevi_device_interface
 	}
 	public static function cpuinfo_core_count()
 	{
+		if(pts_client::executable_in_path('lscpu'))
+		{
+			$lscpu = trim(shell_exec('lscpu -p | egrep -v \'^#\' | sort -u -t, -k 2,4 | wc -l'));
+		}
+
 		$core_count = self::read_cpuinfo_line('cpu cores');
 
 		if($core_count == false || !is_numeric($core_count))
@@ -600,6 +622,10 @@ class phodevi_cpu extends phodevi_device_interface
 		{
 			$core_count = self::cpuinfo_thread_count();
 		}
+		if(is_numeric($lscpu) && $lscpu > $core_count)
+		{
+			$core_count = $lscpu;
+		}
 
 		return $core_count;
 	}
