@@ -163,7 +163,6 @@ class phodevi_disk extends phodevi_device_interface
 		else if(phodevi::is_bsd())
 		{
 			$i = 0;
-
 			do
 			{
 				$disk = phodevi_bsd_parser::read_sysctl('dev.ad.' . $i . '.%desc');
@@ -175,6 +174,18 @@ class phodevi_disk extends phodevi_device_interface
 				$i++;
 			}
 			while(($disk != false || $i < 9) && $i < 128);
+			$i = 0;
+			do
+			{
+				$disk = phodevi_bsd_parser::read_sysctl('dev.nvme.' . $i . '.%desc');
+
+				if($disk != false && strpos($disk, 'DVD') === false && strpos($disk, 'ATAPI') === false)
+				{
+					array_push($disks, $disk);
+				}
+				$i++;
+			}
+			while(($disk != false || $i < 9) && $i < 128);
 			// On some systems, the first drive seems to be at dev.ad.8 rather than starting at dev.ad.0
 
 			if(empty($disks) && pts_client::executable_in_path('camcontrol'))
@@ -230,13 +241,15 @@ class phodevi_disk extends phodevi_device_interface
 				{
 					$disk_size = pts_file_io::file_get_contents($sdx . '/size');
 					$disk_model = pts_file_io::file_get_contents($sdx .  (is_file($sdx . '/device/model') ? '/device/model' : '/device/name'));
-					$disk_removable = pts_file_io::file_get_contents($sdx . '/removable');
 
+					/*
+					$disk_removable = pts_file_io::file_get_contents($sdx . '/removable');
 					if($disk_removable == '1')
 					{
 						// Don't count removable disks
 						continue;
 					}
+					*/
 
 					$disk_size = round($disk_size * 512 / 1000000000) . 'GB';
 					$disk_model = self::prepend_disk_vendor($disk_model);
