@@ -1238,7 +1238,7 @@ class phodevi_gpu extends phodevi_device_interface
 			$info = phodevi_windows_parser::read_cpuz('Display Adapters', 'Name');
 		}
 
-		if(empty($info) || strpos($info, 'Mesa ') !== false || strpos($info, 'Gallium ') !== false)
+		if(empty($info) || strpos($info, 'Mesa ') !== false || strpos($info, 'Gallium ') !== false || strpos($info, ' (DRM') !== false)
 		{
 			if(($x = strpos($info, ' on ')) !== false)
 			{
@@ -1384,6 +1384,11 @@ class phodevi_gpu extends phodevi_device_interface
 			}
 		}
 
+		if(($x = strpos($info, ' (')) !== false)
+		{
+			$info = substr($info, 0, $x);
+		}
+
 		if(empty($info) && isset(phodevi::$vfs->xorg_log))
 		{
 			// ARM Mali DDX driver detection fallback
