@@ -344,6 +344,7 @@ class phodevi_system extends phodevi_device_interface
 							'0xaad7aaea' => 'PanFS', // Panasas FS
 							'0xf2f52010' => 'F2FS',
 							'0xc36400' => 'CephFS',
+							'0x53464846' => 'WSLFS',
 							'0xca451a4e' => 'BcacheFS'
 							);
 
@@ -1336,6 +1337,11 @@ class phodevi_system extends phodevi_device_interface
 			$desktop_environment = 'IceWM';
 			$desktop_version = null;
 		}
+		else if(pts_client::is_process_running('budgie-panel') || $desktop_session == 'budgie-desktop')
+		{
+			// Budgie
+			$desktop_environment = 'Budgie';
+		}
 
 		if(!empty($desktop_environment))
 		{
@@ -1639,7 +1645,7 @@ class phodevi_system extends phodevi_device_interface
 				$info = trim(substr($info, 0, strpos($info, "\n")));
 			}
 		}
-
+		/*
 		if($info == null)
 		{
 			// A less than ideal fallback for some detection now
@@ -1654,6 +1660,7 @@ class phodevi_system extends phodevi_device_interface
 				}
 			}
 		}
+		*/
 
 		return $info;
 	}
