@@ -74,7 +74,8 @@ class pts_ResultFileTable extends pts_Table
 		{
 			if($result_object->test_profile->get_identifier() == null)
 			{
-				continue;
+			// XXX FOR PTS 7.2 Let's try this to show all results, see how it works and revisit later TODO if doesn't look good
+			//	continue;
 			}
 
 			if($extra_attributes != null)
@@ -111,20 +112,23 @@ class pts_ResultFileTable extends pts_Table
 			}
 			else
 			{
-				$result_tests[$result_counter] = new pts_graph_ir_value($result_object->test_profile->get_identifier_base_name() . ': ' . $result_object->get_arguments_description());
-				$result_tests[$result_counter]->set_attribute('title', $result_object->get_arguments_description());
-
 				if($result_object->test_profile->get_identifier() != null)
 				{
+					$result_tests[$result_counter] = new pts_graph_ir_value($result_object->test_profile->get_identifier_base_name() . ': ' . $result_object->get_arguments_description());
+					$result_tests[$result_counter]->set_attribute('title', $result_object->get_arguments_description());
 					$result_tests[$result_counter]->set_attribute('href', 'http://openbenchmarking.org/test/' . $result_object->test_profile->get_identifier());
 				}
+				else if($result_object->test_profile->get_title() != null)
+				{
+					$result_tests[$result_counter] = new pts_graph_ir_value($result_object->test_profile->get_title() . ': ' . $result_object->get_arguments_description());
+				}
 			}
 
 			if($result_object->test_profile->get_identifier() == null)
 			{
 				if($result_object->test_profile->get_display_format() == 'BAR_GRAPH')
 				{
-					$result_tests[$result_counter]->set_attribute('alert', true);
+					//$result_tests[$result_counter]->set_attribute('alert', true);
 					foreach($result_object->test_result_buffer->get_buffer_items() as $index => $buffer_item)
 					{
 						$identifier = $buffer_item->get_result_identifier();
