@@ -31,6 +31,10 @@ class pts_network
 	{
 		return self::$network_proxy == false;
 	}
+	public static function get_network_proxy()
+	{
+		return self::$network_proxy;
+	}
 	public static function internet_support_available()
 	{
 		return self::network_support_available() && self::$disable_internet_support == false;
@@ -131,7 +135,7 @@ class pts_network
 
 		if($download_port_number)
 		{
-			curl_setopt($ch, CURLOPT_PORT, $port);
+			curl_setopt($cr, CURLOPT_PORT, $port);
 		}
 
 		if(stripos($download, 'sourceforge') === false)
@@ -163,7 +167,7 @@ class pts_network
 			curl_setopt($cr, CURLOPT_PROXY, self::$network_proxy['proxy']);
 			if(!empty(self::$network_proxy['user']))
 			{
-				curl_setopt($ch, CURLOPT_USERPWD, self::$network_proxy['user'] . ':' . self::$network_proxy['password']);
+				curl_setopt($cr, CURLOPT_USERPWD, self::$network_proxy['user'] . ':' . self::$network_proxy['password']);
 			}
 		}
 
@@ -423,6 +427,14 @@ class pts_network
 				}
 			}
 		}
+		else if(pts_client::executable_in_path('hostname'))
+		{
+			$hostname_i = trim(shell_exec('hostname -I 2>&1'));
+			if(strpos($hostname_i, ' ') === false)
+			{
+				$local_ip = $hostname_i;
+			}
+		}
 
 		return $local_ip;
 	}
