@@ -117,12 +117,7 @@ class pts_render
 		}
 		if(isset($extra_attributes['sort_result_buffer_values']))
 		{
-			$result_object->test_result_buffer->buffer_values_sort();
-
-			if($result_object->test_profile->get_result_proportion() == 'HIB')
-			{
-				$result_object->test_result_buffer->buffer_values_reverse();
-			}
+			$result_object->sort_results_by_performance();
 		}
 		/*if(isset($extra_attributes['remove_noisy_results']))
 		{
@@ -159,7 +154,7 @@ class pts_render
 			$result_identifiers = $result_object->test_result_buffer->get_identifiers();
 
 			// COMPACT PROCESS
-			if(!isset($extra_attributes['compact_to_scalar']) && $result_object->test_profile->get_display_format() == 'LINE_GRAPH' && ($result_file->get_system_count() > 5 || $result_file->is_multi_way_comparison($result_identifiers, $extra_attributes)))
+			if(!isset($extra_attributes['compact_to_scalar']) && $result_object->test_profile->get_display_format() == 'LINE_GRAPH' && ($result_file->get_system_count() > 6 || $result_file->is_multi_way_comparison($result_identifiers, $extra_attributes)))
 			{
 				// If there's too many lines being plotted on line graph, likely to look messy, so convert to scalar automatically
 				$extra_attributes['compact_to_scalar'] = true;
