@@ -148,7 +148,7 @@ class pts_test_result_parser
 
 		return count(self::$monitoring_sensors) > 0;
 	}
-	public static function system_monitor_task_post_test(&$test_run_request)
+	public static function system_monitor_task_post_test(&$test_run_request, $exit_status_pass = true)
 	{
 		$test_directory = $test_run_request->test_profile->get_install_dir();
 		$did_post_result = false;
@@ -209,7 +209,7 @@ class pts_test_result_parser
 				}
 			}
 
-			if($result_value != null && $result_value > 0)
+			if($result_value != null && $result_value > 0 && $exit_status_pass)
 			{
 				// For now it's only possible to return one result per test XXX actually with PTS7 this can be changed....
 				// TODO XXX for some sensors may make sense for min/max values?
@@ -630,11 +630,14 @@ class pts_test_result_parser
 						{
 							// Using ResultBeforeString tag
 							$before_this = array_search($before_string, $r);
-							$possible_res = $r[($before_this - 1)];
-							self::strip_result_cleaner($possible_res, $entry);
-							if($before_this !== false && (!$is_numeric_check || is_numeric($possible_res)))
+							if($before_this && isset($r[($before_this - 1)]))
 							{
-								$test_results[] = $possible_res;
+								$possible_res = $r[($before_this - 1)];
+								self::strip_result_cleaner($possible_res, $entry);
+								if($before_this !== false && (!$is_numeric_check || is_numeric($possible_res)))
+								{
+									$test_results[] = $possible_res;
+								}
 							}
 						}
 						else if(!empty($after_string))
@@ -856,7 +859,7 @@ class pts_test_result_parser
 		else
 		{
 			$first_portion_of_line = substr($template_line, 0, strpos($template_line, $key));
-			if(strpos($output, $first_portion_of_line) !== false)
+			if($first_portion_of_line != null && strpos($output, $first_portion_of_line) !== false)
 			{
 				$search_key = $first_portion_of_line;
 			}
